## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global genname superlu

Name:		SuperLU
Version:	7.0.0
Release:	%autorelease
Summary:	Subroutines to solve sparse linear systems
License:	BSD-2-Clause AND GPL-2.0-or-later
URL:		https://portal.nersc.gov/project/sparse/superlu/
Source0:	https://github.com/xiaoyeli/superlu/archive/v%{version}/%{genname}-%{version}.tar.gz

# Use a pre-made configuration file for Make
Source1:      %{name}-fedora-make.inc.in

Patch0:	%{genname}-removemc64.patch

# Fix ldflags of example files
Patch1:       %{name}-fix_example_builds.patch

BuildRequires: pkgconfig(flexiblas)
%if 0%{?epel}
BuildRequires:	epel-rpm-macros
%endif
BuildRequires:	metis-devel
BuildRequires:	make
BuildRequires:	cmake
BuildRequires:	gcc
BuildRequires:	gcc-gfortran
BuildRequires:	csh

%description
SuperLU contains a set of subroutines to solve a sparse linear system 
A*X=B. It uses Gaussian elimination with partial pivoting (GEPP). 
The columns of A may be preordered before factorization; the 
preordering for sparsity is completely separate from the factorization.

%package devel
Summary:	Header files and libraries for SuperLU development
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel 
The %{name}-devel package contains the header files
and libraries for use with %{name} package.

%package doc
Summary:	Documentation and Examples for SuperLU
BuildArch:	noarch
%description doc
The %{name}-doc package contains all the help HTML documentation.

%prep
%autosetup -n %{genname}-%{version} -N

%patch -P 0 -p1 -b .backup
%patch -P 1 -p1 -b .backup

rm -f make.inc
cp -pf %{SOURCE1} make.inc.in

# Remove bundled BLAS
rm -rf CBLAS

rm -fr SRC/mc64ad.f.bak
find . -type f | sed -e "/TESTING/d" | xargs chmod a-x

# Remove the shippped executables from EXAMPLE
find EXAMPLE -type f | while read file
do
   [ "$(file $file | awk '{print $2}')" = ELF ] && rm $file || :
done

# Change optimization level
sed -e 's|-O0|-O2|g' -i SRC/CMakeLists.txt

%build
%cmake \
   -Denable_internal_blaslib:BOOL=NO \
   -DXSDK_ENABLE_Fortran:BOOL=OFF \
   -DCMAKE_Fortran_FLAGS_RELEASE:STRING="%{__global_fflags}" \
   -DTPL_BLAS_LIBRARIES="`pkg-config --libs flexiblas`" \
   -DTPL_ENABLE_METISLIB:BOOL=ON \
   -DTPL_METIS_INCLUDE_DIRS:PATH=%{_includedir} \
   -DTPL_METIS_LIBRARIES:FILEPATH=%{_libdir}/libmetis.so \
   -DCMAKE_BUILD_TYPE:STRING=Release \
   -DCMAKE_INSTALL_INCLUDEDIR:PATH=include/%{name} \
   -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
   -DCMAKE_SKIP_RPATH:BOOL=YES -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES
%cmake_build

%install
%cmake_install

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}:MATGEN
%ctest

%files
%license License.txt
%{_libdir}/libsuperlu.so.7
%{_libdir}/libsuperlu.so.%{version}

%files devel
%{_includedir}/%{name}/
%{_libdir}/libsuperlu.so
%{_libdir}/cmake/%{genname}/
%{_libdir}/pkgconfig/%{genname}.pc

%files doc
%license License.txt
%doc DOC

%changelog
## START: Generated by rpmautospec
* Thu Sep 05 2024 Antonio Trande <sagitter@fedoraproject.org> - 7.0.0-1
- Release 7.0.0

* Wed Jul 17 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Wed Apr 10 2024 Antonio Trande <sagitter@fedoraproject.org> - 6.0.1-7
- Release number bump

* Sun Apr 07 2024 Miroslav Suchý <msuchy@redhat.com> - 6.0.1-6
- Correct typo in SPDX license

* Sun Mar 31 2024 Antonio Trande <sagitter@fedoraproject.org> - 6.0.1-5
- Fix Changelog

* Sun Mar 31 2024 Antonio Trande <sagitter@fedoraproject.org> - 6.0.1-4
- Build against Flexiblas in EPEL9 (rhbz#2257325)

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Oct 15 2023 Antonio Trande <sagitter@fedoraproject.org> - 6.0.1-1
- Release 6.0.1

* Sat Jul 15 2023 Antonio Trande <sagitter@fedoraproject.org> - 6.0.0-1
- Release 6.0.0

* Tue Feb 21 2023 Florian Weimer <fweimer@redhat.com> - 5.3.0-5
- Port to C99

* Wed Jan 18 2023 Fedora Release Engineering <releng@fedoraproject.org> - 5.3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Jul 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 5.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jan 19 2022 Fedora Release Engineering <releng@fedoraproject.org> - 5.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Oct 30 2021 Antonio Trande <sagitter@fedoraproject.org> - 5.3.0-1
- Release 5.3.0

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jan 29 2021 Antonio T <sagitter@fedoraproject.org> - 5.2.2-1
- Release 5.2.2

* Mon Jan 25 2021 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.1-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jan 12 2021 Tom Stellard <tstellar@redhat.com> - 5.2.1-19
- Add BuildRequires: make

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.1-18
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.1-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jul 25 2020 Iñaki Úcar <iucar@fedoraproject.org> - 5.2.1-16
- https://fedoraproject.org/wiki/Changes/FlexiBLAS_as_BLAS/LAPACK_manager

* Wed Jul 22 2020 sagitter <sagitter@fedoraproject.org> - 5.2.1-15
- Bump release version

* Tue Jul 21 2020 Merlin Mathesius <mmathesi@redhat.com> - 5.2.1-14
- Minor conditional fix for ELN Stick to cmake in-source building

* Sun Apr 19 2020 sagitter <sagitter@fedoraproject.org> - 5.2.1-13
- Doc sub-package provides its own license file

* Sat Apr 18 2020 sagitter <sagitter@fedoraproject.org> - 5.2.1-12
- Some minor fixes| Do not pack example's source code

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.1-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jan 28 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 5.2.1-8
- Fix RHEL conditions

* Fri Sep 14 2018 sagitter <sagitter@fedoraproject.org> - 5.2.1-7
- Change optimization level from upstream

* Fri Sep 14 2018 sagitter <sagitter@fedoraproject.org> - 5.2.1-6
- Do not use %%%%ctest3

* Fri Sep 14 2018 sagitter <sagitter@fedoraproject.org> - 5.2.1-5
- Remove gcc-gfortran as required package

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Apr 25 2018 sagitter <sagitter@fedoraproject.org> - 5.2.1-3
- Patch soname (5 -> 5.2) of shared library

* Tue Apr 17 2018 sagitter <sagitter@fedoraproject.org> - 5.2.1-2
- Use cmake3 on rhel; use blas from system

* Fri Apr 13 2018 Rafael dos Santos <rdossant@redhat.com> - 5.2.1-1
- Update to 5.2.1
- Resolves #1547494
- Use cmake

* Wed Feb 21 2018 sagitter <sagitter@fedoraproject.org> - 5.2.0-9
- Add gcc BR

* Thu Feb 15 2018 sagitter <sagitter@fedoraproject.org> - 5.2.0-8
- Rebuild for libsbml-5.16.0

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Dec 01 2017 Mukundan Ragavan <nonamedotc@gmail.com> - 5.2.0-6
- Fix lib linking in EPEL (added conditionals; Thanks Antonio Trande)) Use
  license macro

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.0-5
- Rebuilt for
  https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Apr 14 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.2.0-2
- Update to 5.2.0
- spec file cleanup

* Thu Apr 14 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.2.0-1
- Update to 5.2.0
- spec file cleanup

* Tue Mar 29 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.1.1-2
- Added -doc subpackage
- Added GPLv2 in the license field

* Sat Mar 26 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.1.1-1
- Update to 5.1.1
- Remove format security patch - not needed anymore
- Edit patches to be version specific
- Renamed patch4 to be consistent with others
- Minor spec file housekeeping

* Wed Feb 03 2016 Dennis Gilmore <dennis@ausil.us> - 4.3-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jun 16 2015 Dennis Gilmore <dennis@ausil.us> - 4.3-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jan 26 2015 nonamedotc <nonamedotc@fedoraproject.org> - 4.3-10
- Fix spec file errors and remove backup files
- fixes 1084707

* Fri Aug 15 2014 Peter Robinson <pbrobinson@fedoraproject.org> - 4.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jul 13 2014 nonamedotc <nonamedotc@fedoraproject.org> - 4.3-8
- Removed non-free files, fixes bz#1114264

* Fri Jun 06 2014 Dennis Gilmore <dennis@ausil.us> - 4.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Jan 06 2014 Björn Esser <bjoern.esser@gmail.com> - 4.3-6
- fixed FTBFS if "-Werror=format-security" flag is used (#1037343) devel-
  pkg must Requires: %%%%{name}%%%%{?_isa} apply proper LDFLAGS added
  needed bits for el5 reenable testsuite using Patch3

* Fri Oct 04 2013 Orion Poplawski <orion@nwra.com> - 4.3-5
- Rebuild for atlas 3.10 - Handle UnversionedDocDirs change

* Fri Aug 02 2013 Dennis Gilmore <dennis@ausil.us> - 4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Mar 25 2013 Shakthi Kannan <skannan@redhat.com> - 4.3-3
- Ship examples

* Wed Feb 13 2013 Dennis Gilmore <dennis@ausil.us> - 4.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Aug 31 2012 Shakthi Kannan <skannan@redhat.com> - 4.3-1
- First release
## END: Generated by rpmautospec
